@@ -3,7 +3,8 @@ from oracle.Prediction import Prediction
 
 class Oracle:
 
-    # todo: need a way to inject data (needs to be at run -> should be high level data)
+    def set_data(self, data):
+        pass
 
     def predict(self, instrument) -> Prediction:
         pass
