@@ -9,19 +9,20 @@ class PredictionResolver:
     def __init__(self, oracles):
         self.oracles: List[Oracle] = oracles
 
-    # todo: position + data needs to be injected (at run)
-    # todo: test with 'simple oracles'
-    def resolve(self):
-        predictions = self.collect_predictions_from_all_oracles()
+    def resolve(self, instrument, data):
+        self.set_all_oracle_with_data(data)
+        predictions = self.collect_predictions_from_all_oracles(instrument)
         best_prediction = self.determine_best_profitable_prediction(predictions)
         return best_prediction
 
-    def collect_predictions_from_all_oracles(self) -> List[Prediction]:
+    def set_all_oracle_with_data(self, data):
+        for oracle in self.oracles:
+            oracle.set_data(data)
+
+    def collect_predictions_from_all_oracles(self, instrument) -> List[Prediction]:
         predictions = []
         for oracle in self.oracles:
-            # todo: need instrument (could be position <- instrument)
-            # todo: what to predict from (data - high level interface)
-            prediction = oracle.predict()
+            prediction = oracle.predict(instrument)
             predictions.append(prediction)
         valid_predictions = [p for p in predictions if p is not None]
         return valid_predictions
